@@ -49,6 +49,8 @@ class CapabilityType(IntEnum):
     CAMERA_DVR_CAPABLE = 72
     CANNOT_REPORT_STATUS = 33
     CAN_CHIME = 4
+    CAN_ENABLE_DISABLE_AUDIO = 73
+    CAN_ENABLE_DISABLE_LED = 74
     CAN_INITIATE_CALL = 66
     CAN_LOCK_UNLOCK = 30
     CHIME_EXTENDER = 36
@@ -72,6 +74,7 @@ class CapabilityType(IntEnum):
     FAN480_MINUTE = 25
     FAN960_MINUTE = 26
     HAS_MICROPHONE = 46
+    HAS_USER_CODE = 75
     HSB_LIGHTING = 9
     HUMIDITY = 64
     HUMIDITY_CONTROL = 65
@@ -149,8 +152,8 @@ class DeviceType(Enum):
 class EquipmentCode(IntEnum):
     """Equipment code."""
 
-    APOLLO_COMBO_CO = 1422
-    APOLLO_COMBO_SMOKE = 1322
+    APOLLO_COMBO_CO = 4050
+    APOLLO_COMBO_SMOKE = 4040
     CARBON_MONOXIDE_DETECTOR_345_MHZ = 1254
     CO1_CO = 860
     CO1_CO_CANADA = 859
@@ -158,6 +161,7 @@ class EquipmentCode(IntEnum):
     DBELL1_2_GIG_DOORBELL = 1063
     DW10_THIN_DOOR_WINDOW = 862
     DW11_THIN_DOOR_WINDOW = 1251
+    DW12_THIN_DOOR_WINDOW = 4000
     DW20_RECESSED_DOOR = 863
     DW21_R_RECESSED_DOOR = 1252
     EXISTING_CO = 692
@@ -172,6 +176,7 @@ class EquipmentCode(IntEnum):
     GARAGE01_RESOLUTION_TILT = 1061
     GB1_GLASS_BREAK = 864
     GB2_GLASS_BREAK = 1248
+    GB3_GLASS_BREAK = 4030
     HW_DW_5816 = 673
     HW_FLOOD_SENSOR_5821 = 624
     HW_GLASS_BREAK_5853 = 519
@@ -186,8 +191,10 @@ class EquipmentCode(IntEnum):
     PAD1_345_WIRELESS_KEYPAD = 867
     PANIC1 = 868
     PANIC2 = 1253
+    PANIC3 = 4130
     PIR1_MOTION = 869
     PIR2_MOTION = 1249
+    PIR3_MOTION = 4020
     RE219_FLOOD_SENSOR = 1128
     RE220_T_2_GIG_REPEATER = 1144
     RE224_DT_DSC_TRANSLATOR = 1208
